# -*- coding: utf-8 -*-
from setuphelpers import *
import pprint

rsat_capabilities = [
    "Rsat.ActiveDirectory.DS-LDS.Tools~~~~0.0.1.0",
    "Rsat.BitLocker.Recovery.Tools~~~~0.0.1.0",
    "Rsat.CertificateServices.Tools~~~~0.0.1.0",
    "Rsat.DHCP.Tools~~~~0.0.1.0",
    "Rsat.Dns.Tools~~~~0.0.1.0",
    "Rsat.FailoverCluster.Management.Tools~~~~0.0.1.0",
    "Rsat.FileServices.Tools~~~~0.0.1.0",
    "Rsat.GroupPolicy.Management.Tools~~~~0.0.1.0",
    "Rsat.IPAM.Client.Tools~~~~0.0.1.0",
    "Rsat.LLDP.Tools~~~~0.0.1.0",
    "Rsat.NetworkController.Tools~~~~0.0.1.0",
    "Rsat.NetworkLoadBalancing.Tools~~~~0.0.1.0",
    "Rsat.RemoteAccess.Management.Tools~~~~0.0.1.0",
    "Rsat.RemoteDesktop.Services.Tools~~~~0.0.1.0",
    "Rsat.ServerManager.Tools~~~~0.0.1.0",
    "Rsat.Shielded.VM.Tools~~~~0.0.1.0",
    "Rsat.StorageMigrationService.Management.Tools~~~~0.0.1.0",
    "Rsat.StorageReplica.Tools~~~~0.0.1.0",
    "Rsat.SystemInsights.Management.Tools~~~~0.0.1.0",
    "Rsat.VolumeActivation.Tools~~~~0.0.1.0",
    "Rsat.WSUS.Tools~~~~0.0.1.0",
]
# rsat_capabilities_to_install = rsat_capabilities
rsat_capabilities_to_install = [
    "Rsat.ActiveDirectory.DS-LDS.Tools~~~~0.0.1.0",
    "Rsat.BitLocker.Recovery.Tools~~~~0.0.1.0",
    "Rsat.Dns.Tools~~~~0.0.1.0",
    "Rsat.GroupPolicy.Management.Tools~~~~0.0.1.0",
    "Rsat.LLDP.Tools~~~~0.0.1.0",
    "Rsat.RemoteAccess.Management.Tools~~~~0.0.1.0",
]


def install():
    # Declaring local variables
    try:
        rsat_binaries_zip = glob.glob("rsat_*.zip")[0]
        unzip(rsat_binaries_zip, ".")
        rsat_binaries_dir = rsat_binaries_zip.split(".")[0]
    except:
        rsat_binaries_dir = glob.glob("rsat_*")[0]
    rsat_source_path = makepath(os.getcwd(), rsat_binaries_dir)
    app_error = False

    # Installing the package
    with EnsureWUAUServRunning():
        for capability in rsat_capabilities_to_install:
            print("Installing: %s" % capability)
            try:
                run_powershell('Add-WindowsCapability -Online -Name "%s" -LimitAccess -Source "%s"' % (capability, rsat_source_path))
            except:
                print("Installation failed for: %s" % capability)
                app_error = True

    if app_error:
        error("RSAT capabilities to install do not succeed completely. You may need to restart the computer and try again")


def uninstall():
    # Declaring local variables
    app_error = False

    # Uninstalling the package
    print("Uninstalling all RSAT features")
    with EnsureWUAUServRunning():
        for capability in rsat_capabilities:
            print("Uninstalling: %s" % capability)
            try:
                run_powershell('Remove-WindowsCapability -Online -Name "%s"' % capability)
            except:
                print("Uninstallation failed on: %s" % capability)
                app_error = True

    if app_error and not params.get("running_as_luti"):
        error("RSAT capabilities uninstallation do not succeed completely. You may need to restart the computer and try again")


def audit():
    # Manually check in PowerShell: Get-WindowsCapability -online | ? Name -like Rsat* | FT
    print("Showing installed RSAT features:")
    pprint.pprint(run_powershell("Get-WindowsCapability -Online | Where Name -like Rsat* | Where State -Like Installed | Select Name,RestartNeeded"))
    print("Showing NOT installed RSAT features:")
    pprint.pprint(
        run_powershell("Get-WindowsCapability -Online | Where Name -like Rsat* | Where State -NotLike Installed | Select Name,RestartNeeded")
    )
    return "OK"
